//-----------------------------------------------------------------------------
//
//                      XMM Science Analysis System (SAS)
//                     (c) 1997-2010 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	  lut2xcolorcod.cc	--- convert SAO LUT color tables to xcolorcod format
//
//	DESCRIPTION:
//		Convert a given SAO LUT (LookUp Table) ASCII colortable to xcolorcod
//		format.
//		Usage is:
//			lut2xcolorcod outsetname
//		LUT color table is read from stdin; xcolorcod color table is
//		written to dataset <outsetname>.ds in CWD.
//
//	CHANGE HISTORY:
//		UL, 2002-02-19: 1.0.0: - first version
//
//	AUTHORS:
//		Uwe Lammers (UL), Wed Feb 19 15:38:04 MET 2003
// 
// $Header: /sasbuild/repositories/sasdev/sas/packages/xcolorcod/colortable/lut2xcolorcod.cc,v 1.1 2003/02/21 11:08:42 ulammers Exp $
//
#include <cstdlib>
#include <iostream>
#include <string>

#include "stringutil.h"
#include "common.h"
#include "../src/ColorTable.h"

using namespace std;

class LUTColorTableFile {
public:
	LUTColorTableFile(istream &is) : _is(&is), _lineNr(0) {}

	vector<Color> scan() const {
		string line;
		vector<Color> cols;
		while (getline(*_is, line) && _is->good()) {
			_lineNr++;
			line = trim(line, true);
			if (line.empty() || line[0] == '#')
				//  empty or comment line
				continue;

			if (line.empty() || !_is->good())
				err();

			vector<string> v = breakup(line);
			if (v.size() != 3)
				err();

			cols.push_back(Color(toNumber<double>(v[0]),
								 toNumber<double>(v[1]),
								 toNumber<double>(v[2])));
		}

		return cols;
	}

private:
	istream	*_is;
	mutable unsigned	_lineNr;

	void err() const {
		cerr<<"LUTimage color table syntax error in line #"<<_lineNr<<endl;
		exit(1);
	}
};

int main(int argc, char **argv)
{
	if (argc != 2) {
		cerr<<"Usage: "<<argv[0]<<" outsetname\n";
		return 1;
	}

	LUTColorTableFile ctf(cin);
	vector<Color> cols = ctf.scan();
	//	construct resulting color table
	ColorTable cTab;
	unsigned N = cols.size();
	for (unsigned n=0; n<N; ++n)
		cTab[DBL(n)/DBL(N-1)] = cols[n];

	cTab.toDataSet(argv[1]);
	return 0;
} // main()
