//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//					   (c) 1997-2010 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	ColorImage: A class representing a color image
//
//	DESCRIPTION:
//		A class that represents a color image; offers methods to manipulate
//		the image;
//
//	CHANGE HISTORY:
//		MB, 1999-??-??: 1.0.0: - first version
//
//	AUTHORS:
//		M. Beijersbergen (MB)
//		U. Lammers (UL), Mon Jul 17 13:46:09 MET DST 2000
//
//	REFERENCES:
//		[1]: Software Specification Document for the XMM Science Analysis
//			 Subsystem, M. Dahlem et. al.,
//
//	$Header: /sasbuild/repositories/sasdev/sas/packages/xcolorcod/src/ColorImage.h,v 1.7 2013/08/02 12:09:09 aibarra Exp $
//
#ifndef COLORIMAGE_H
#define COLORIMAGE_H

#include <string>
#include <vector>
#include "Dal.h"
#include "Color.h"

using namespace std;

class ColorImage {
public:
	ColorImage(int nx = 0, int ny = 0);
    ~ColorImage();

	void size(int nx, int ny);

	double max() const;

	Color& operator()(int ix, int iy);
	const Color& operator()(int ix, int iy) const;

	void normalize(double max);

	void add(ColorImage* image,vector<double> weight);

	void applyWeight(vector<double> weight);

	void setTrueColor(bool trueColor = false);

	void logScale(double binSize, double scalMin, double scalMax);

	void log(double decades);

	void writePPM(std::ostream& os) const;

	void writeDataSet(const std::string &name,
			std::vector<std::string> evlistFileName,
			bool asCube = false, double scalmin = 0.0 ,
			double scalmax = 0.0);

	void setExposure(string exp) { _exposure << exp << " ";}
	string getExposure() { return _exposure.str(); }

	void setInstrument(string instr) {_instrument << instr<<" ";}
	string getInstrument() {return _instrument.str();}

	void setFilter(string filter) {_filter << filter<<" ";}
	string getFilter() {return _filter.str();}


private:
	Color	*_pixels;
	int		_nx, _ny;
	double _max;

	bool _trueColor;
	
	stringstream _exposure;
	stringstream _instrument;
	stringstream _filter;
	
	bool isTrueColor();
	void writeAsRGBarrays(DataSet *set);
	void writeAsDataCube(DataSet *set,std::vector<std::string> ev,
			double scalmin, double scalmax);
};

#endif
