//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//					   (c) 1997-2010 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	ColorTable.cc: Implementation of ColorTable class.
//
//	DESCRIPTION:
//		Implementation of ColorTable class
//
//	CHANGE HISTORY:
//		UL, 2003-02-18: 1.0.0: - first version
//
//	AUTHORS:
//		U. Lammers (UL), Tue Feb 18 17:45:44 MET 2003
//
//	REFERENCES:
//		[1]: Software Specification Document for the XMM Science Analysis
//			 Subsystem, M. Dahlem et. al.,
//
//	$Header: /sasbuild/repositories/sasdev/sas/packages/xcolorcod/src/ColorTable.cc,v 1.2 2013/08/02 12:09:09 aibarra Exp $
//
#include "common.h"
#include "Dal.h"

#include "ColorTable.h"

using namespace std;

const string ColorTable::RED_COL("RED"),
			 ColorTable::GREEN_COL("GREEN"),
			 ColorTable::BLUE_COL("BLUE"),
			 ColorTable::LEVEL_COL("LEVEL"),
			 ColorTable::TABNAME("COLORTABLE");

ColorTable::ColorTable(const std::string &colorSetName, bool invert)
{
	Table *table =
				dataSetServer->open(colorSetName, Dal::Read)->table(TABNAME);

	ColumnData *ld = table->column(LEVEL_COL)->data(),
			   *rd = table->column(RED_COL)->data(),
			   *gd = table->column(GREEN_COL)->data(),
			   *bd = table->column(BLUE_COL)->data();
	real32	   *l = ld->real32Data(),
			   *r = rd->real32Data(),
			   *g = gd->real32Data(),
			   *b = bd->real32Data();

	unsigned N = table->rows();
	for (unsigned n=0; n<N; ++n)
		(*this)[!invert ? l[n] : 1.-l[n]] += Color(r[n], g[n], b[n]);

	delete ld;
	delete rd;
	delete gd;
	delete bd;

	dataSetServer->close(table->parent());
} // ColorTable::ColorTable()

//	write to data set
void ColorTable::toDataSet(const std::string &colorSetName) const
{
	Table *table = dataSetServer->open(colorSetName, Dal::Create)
						->addTable(TABNAME, size(), "RGB color table");
	Column *cols[] = {
				table->addColumn(LEVEL_COL, Dal::Real32, "scalar level"),
				table->addColumn(RED_COL, Dal::Real32, "red component"),
				table->addColumn(GREEN_COL, Dal::Real32, "green component"),
				table->addColumn(BLUE_COL, Dal::Real32, "blue component")
			};

	const unsigned N = NUM_OF(cols);
	ColumnData *cd[N];
	real32 *d[N];
	for (unsigned n=0; n<N; ++n) {
		*cols[n]->addAttribute("TLMIN", "minimum legal value") = 0.;
		*cols[n]->addAttribute("TLMAX", "maximum legal value") = 1.;
		cd[n] = cols[n]->data();
		d[n] = cd[n]->real32Data();
	}

	unsigned n=0;
	for (const_iterator i = begin(); i != end(); ++i) {
		d[0][n] = i->first;
		d[1][n] = i->second.red;
		d[2][n] = i->second.green;
		d[3][n++] = i->second.blue;
	}

	for (unsigned n=0; n<N; ++n)
		delete cd[n];

	dataSetServer->close(table->parent());
} // ColorTable::toDataSet()
