//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//					   (c) 1997-2010 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	ColorTable: A class representing a color table
//
//	DESCRIPTION:
//		A color table defines a mapping of single scalar values onto
//		RGB tuples. It can be stored in tabular form with four columns
//		Level/R/G/B; methods for reading/writing color tables and
//		conversion from SAOimage ASCII color table format are provided;
//		the level-axis is made continuous through piecewise-linear
//		interpolation of given discrete data points in table
//
//	CHANGE HISTORY:
//		2003-02-18:	1.0.0	: first version
//
//	AUTHOR:
//		U. Lammers (UL), Tue Feb 18 15:27:17 MET 2003
//
//	REFERENCES:
//		[1]: Software Specification Document for the XMM Science Analysis
//			 Subsystem, M. Dahlem et. al.,
//
//	$Header: /sasbuild/repositories/sasdev/sas/packages/xcolorcod/src/ColorTable.h,v 1.1 2003/03/03 11:13:59 ulammers Exp $: /usr/local/cvs/sasdev/task_devel/packages/xcolorcod/src/Color.h,v 1.4 2003/01/21 12:34:51 ulammers Exp $
//
#ifndef COLOR_TABLE_H
#define COLOR_TABLE_H

#include <string>

#include "Color.h"
#include "LinearlyInterpolatedPointsCurve.h"

class ColorTable : public LinearlyInterpolatedPointsCurve<double, Color> {
public:
	//	construct empty table
	ColorTable() {}

	//	construct from data set
	ColorTable(const std::string &colorSetName, bool invert=false);

	//	write to data set
	void toDataSet(const std::string &colorSetName) const;

	~ColorTable() {}

private:
	static const std::string RED_COL, GREEN_COL, BLUE_COL, LEVEL_COL,
							 TABNAME;
						
};

#endif
