//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//					   (c) 1997-2010 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	LinearlyInterpolatedPointsCurve.h
//
//	CHANGE HISTORY:
//		MB, 1999-??-??: 1.0.0: - first version
//
//	DESCRIPTION:
//		Implementation of an InterpolatedPointsCurve, which will linearly
//		interpolate between the points in the map.
//
//	AUTHOR:
//		Marco Beijersbergen (MB), cosine (mbeijers@cosine.nl)
//
//	REFERENCES:
//		[1]: Software Specification Document for the XMM Science Analysis
//			 Subsystem, M. Dahlem et. al.,
//
//	$Header: /sasbuild/repositories/sasdev/sas/packages/xcolorcod/src/LinearlyInterpolatedPointsCurve.h,v 1.5 2009/09/01 15:25:38 aibarra Exp $
//
#ifndef LINEARLY_INTERPOLATED_POINTS_CURVE_H
#define LINEARLY_INTERPOLATED_POINTS_CURVE_H

#include "InterpolatedPointsCurve.h"


template<class X, class Y>
class LinearlyInterpolatedPointsCurve : public InterpolatedPointsCurve<X,Y> {
public:
	Y operator()(const X& x) const {
		/* AI gcc4 porting
		 * error: no matching function for call to ‘lower_bound(const double&)’
		 */
		typename std::map<X,Y>::const_iterator i = this->lower_bound(x);
		/* AI gcc4 porting
		 * error: there are no arguments to ‘end’ that depend on a template parameter, so a declaration of ‘end’ must be available
		 * => this->end() // this->begin()
		 */
		if (i == this->end()) {
			typename std::map<X,Y>::const_iterator i = this->end();
			--i;
			return (*i).second;
		}
		if (i == this->begin()) return (*this->begin()).second;
		typename std::map<X,Y>::const_iterator prev = i;
		--prev;
		return (*prev).second +
			(x-(*prev).first)/((*i).first-(*prev).first) *
			((*i).second-(*prev).second);
	}
};

#endif


