//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//					   (c) 1997-2010 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	TableBasedPseudoRGBImage : RGB image in the form of a table
//
//	DESCRIPTION:
//		A class that represents an RGB image in the form of a table
//		with three columns "RED"/"GREEN"/"BLUE"; can be binned with
//		evselect to get a 2D image.
//
//	CHANGE HISTORY:
//		UL, 2000-07-17: 1.0.0: - first version
//
//	AUTHOR:
//		U. Lammers (UL), Mon Jul 17 13:46:09 MET DST 2000
//
//	REFERENCES:
//		[1]: Software Specification Document for the XMM Science Analysis
//			 Subsystem, M. Dahlem et. al.,
//
//	$Header: /sasbuild/repositories/sasdev/sas/packages/xcolorcod/src/TableBasedPseudoRGBImage.h,v 1.9 2013/08/02 12:09:09 aibarra Exp $
//

#ifndef TABLE_BASED_RGB_IMAGE_H
#define TABLE_BASED_RGB_IMAGE_H

#include <string>
#include "Color.h"
#include "ColorImage.h"
#include "LinearlyInterpolatedPointsCurve.h"
#include "Dal.h"

using namespace std;

class TableBasedPseudoRGBImage {
public:
	enum MinMaxDeterminationScheme { ACTUAL, LEGAL, EXPLICIT };
	TableBasedPseudoRGBImage(
			const string &table,
			const string &xCol,
			const string &yCol,
			const string &eCol,
			MinMaxDeterminationScheme minMaxScheme,
			double minVal, double maxVal,
			const LinearlyInterpolatedPointsCurve<double,Color> &colorCurve);

	ColorImage *toColorImage() const;
	ColorImage *toTrueColorImage() const;

	~TableBasedPseudoRGBImage();

private:
	string		_tempTableName;
	ColumnData	*_cdr,
				*_cdg,
				*_cdb;
	real32		*_r, *_g, *_b;

	double _livetime;

	//etruecolor assume that the input event files have the 
	//same astrometry origin. This fix has been introduced after 
	//runnning etruecolor with mosaicing images.
	//double _ra_pnt;
	//double _dec_pnt;
};

#endif
